aboutsummaryrefslogtreecommitdiff
path: root/video/codecs/truemotion1.h
diff options
context:
space:
mode:
authorEugene Sandulenko2011-01-23 19:08:09 +0000
committerEugene Sandulenko2011-01-23 19:08:09 +0000
commitcaa6684752a310e916b179125a4125a8b3be36f0 (patch)
treedc364d58619b297194bc5d0673b694c34fb51b6c /video/codecs/truemotion1.h
parent3d15871ee2d6a9c0ce4819a6ab5925638bafa8b9 (diff)
downloadscummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.gz
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.bz2
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.zip
VIDEO: Move video classes to Video:: namespace
svn-id: r55479
Diffstat (limited to 'video/codecs/truemotion1.h')
-rw-r--r--video/codecs/truemotion1.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/video/codecs/truemotion1.h b/video/codecs/truemotion1.h
index c80598afdc..4a51fcb33a 100644
--- a/video/codecs/truemotion1.h
+++ b/video/codecs/truemotion1.h
@@ -33,20 +33,20 @@
#include "video/codecs/codec.h"
-namespace Graphics {
+namespace Video {
class TrueMotion1Decoder : public Codec {
public:
TrueMotion1Decoder(uint16 width, uint16 height);
~TrueMotion1Decoder();
- const Surface *decodeImage(Common::SeekableReadStream *stream);
+ const Graphics::Surface *decodeImage(Common::SeekableReadStream *stream);
// Always return RGB565
- PixelFormat getPixelFormat() const { return Graphics::PixelFormat(2, 5, 6, 5, 0, 11, 5, 0, 0); }
+ Graphics::PixelFormat getPixelFormat() const { return Graphics::PixelFormat(2, 5, 6, 5, 0, 11, 5, 0, 0); }
private:
- Surface *_surface;
+ Graphics::Surface *_surface;
int _mbChangeBitsRowSize;
byte *_buf, *_mbChangeBits, *_indexStream;
@@ -100,7 +100,7 @@ private:
void genVectorTable16(const byte *selVectorTable);
};
-} // End of namespace Graphics
+} // End of namespace Video
#endif // VIDEO_CODECS_TRUEMOTION1_H
#endif // SCI32/Plugins guard